===============
pipecashagents
===============


.. image:: https://img.shields.io/pypi/v/pipecashagents.svg
        :target: https://pypi.python.org/pypi/pipecashagents

.. image:: https://img.shields.io/travis/Pipe-Cash/pipecashagents.svg
        :target: https://travis-ci.org/Pipe-Cash/pipecashagents

.. image:: https://readthedocs.org/projects/pipecashagents/badge/?version=latest
        :target: https://pipecashagents.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/Pipe-Cash/pipecashagents/shield.svg
     :target: https://pyup.io/repos/github/Pipe-Cash/pipecashagents/
     :alt: Updates



A collection of common agents used in PipeCash. Learn more about PipeCash on http://pipe.cash/


* Free software: MIT license
* Documentation: https://pipecashagents.readthedocs.io.




Installation
----------------

pip install pipecashwallets

Usage
--------

This package is not intended for direct usage.
Simply install it and reference its modules in your PipeCash configurations.

Contributing
----------------

All pull requests are wellcome.

The areas that need the most help are:

- Write agents
- Testing
- Documentation
